==> llvm-toolchain-10_10.0.0~+rc1.orig.tar.xz: llvm-toolchain-10_10.0.0~+rc1/openmp/runtime/test/ompt/synchronization/reduction/tree_reduce.c <==
// RUN: %libomp-compile-and-run | %sort-threads | FileCheck %s
// REQUIRES: ompt
// UNSUPPORTED: gcc
#include "callback.h"
#include <omp.h>

#ifdef NOWAIT
#define FOR_CLAUSE nowait
#else
#define FOR_CLAUSE
#endif

int main() {
  int sum = 0;
  int i;
#pragma omp parallel num_threads(5)
#pragma omp for reduction(+ : sum) FOR_CLAUSE
  for (i = 0; i < 10000; i++) {
    sum += i;
  }

  // CHECK: 0: NULL_POINTER=[[NULL:.*$]]

  // CHECK: {{^}}[[MASTER_ID:[0-9]+]]: ompt_event_parallel_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID:[0-9]+]]
  // CHECK: {{^}}[[MASTER_ID]]: ompt_event_implicit_task_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id=[[TASK_ID:[0-9]+]]

  // order and distribution to threads not determined
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_end:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_end:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_end:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_end:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}

  return 0;
}

==> llvm-toolchain-19_19.1.7.orig.tar.xz: llvm-toolchain-19_19.1.7/openmp/runtime/test/ompt/synchronization/reduction/tree_reduce.c <==
// RUN: %libomp-compile-and-run | %sort-threads | FileCheck %s
// RUN: %libomp-compile -DNOWAIT && %libomp-run | %sort-threads | FileCheck %s
// REQUIRES: ompt
// UNSUPPORTED: gcc
#include "callback.h"
#include <omp.h>

#ifdef NOWAIT
#define FOR_CLAUSE nowait
#else
#define FOR_CLAUSE
#endif

int main() {
  int sum = 0, a = 0, b = 0;
  int i;
#pragma omp parallel num_threads(5)
// for 32-bit architecture we need at least 3 variables to trigger tree
#pragma omp for reduction(+ : sum, a, b) FOR_CLAUSE
  for (i = 0; i < 10000; i++) {
    a = b = sum += i;
  }


  printf("%i\n", sum);
  // CHECK: 0: NULL_POINTER=[[NULL:.*$]]

  // CHECK: {{^}}[[MASTER_ID:[0-9]+]]: ompt_event_parallel_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID:[0-9]+]]
  // CHECK: {{^}}[[MASTER_ID]]: ompt_event_implicit_task_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id=[[TASK_ID:[0-9]+]]

  // order and distribution to threads not determined
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_end:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_end:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_end:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_begin:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}
  // CHECK: {{^}}{{[0-f]+}}: ompt_event_reduction_end:
  // CHECK-SAME: parallel_id=[[PARALLEL_ID]], task_id={{[0-9]+}}

  return 0;
}
